package com.malk.xiding.schedule;

import com.malk.xiding.server.XDConf;
import com.malk.xiding.service.XDService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.util.Date;

/**
 * @EnableScheduling 开启桑诺定时任务 [配置参考McScheduleTask]
 */
@Slf4j
@Configuration
@EnableScheduling
@ConditionalOnProperty(name = {"spel.scheduling"})
public class XDScheduleTask {

    @Autowired
    private XDService xdService;

    /**
     * [定时同步审批单]
     * 每天8点, 流程搜索按照发起和结束时间, 兼容性同步15内审批单
     */
    @Scheduled(cron = "0 0 8 1/1 * ?")
    public void Time_Period_1() {
        try {
            log.info("###### [XD]同步审批单开始 ######");
            long endTime = new Date().getTime();
            long startTime = endTime - 15 * 24 * 60 * 60 * 1000L;
            xdService.syncApprove(startTime, endTime, XDConf.TMP_CODE_CC, "出差");
            xdService.syncApprove(startTime, endTime, XDConf.TMP_CODE_WC, "外出");
        } catch (Exception e) {
            log.error(e.getMessage(), e); // 记录错误日志
        }
        log.info("###### [XD]同步审批单结束 ######");
    }

    @Scheduled(cron = "0 5/10 9,10,15 1/1 * ?")
    public void Time_Period_2() {
        syncAttendance2DD();
    }

    @Scheduled(cron = "0 5/10 16-23 1/1 * ?")
    public void Time_Period_3() {
        syncAttendance2DD();
    }

    /**
     * [频率为每10分钟查询一次]
     * 09:00~11:00同步签到数据: 11点前纷享销客签到同步钉钉上班, 打卡为09:00
     * 16:00 -23:59 同步签退数据: 下午4点前纷享销容签退, 同步钉钉打卡为18:00
     */
    private void syncAttendance2DD() {
        log.info("###### [XD]同步考勤开始 ######");
        Date eTime = new Date();
        Date sTime = new Date(eTime.getTime() - 11 * 60 * 1000L);
        try {
            xdService.syncAttendance(0, sTime, eTime);
        } catch (Exception e) {
            log.error(e.getMessage(), e); // 记录错误日志
        }
        log.info("###### [XD]同步考勤结束 ######");
    }
}