package com.malk.server.dingtalk;

import com.alibaba.fastjson.JSON;
import com.malk.Util.UtilMap;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class DDFormComponentDto {

    /**
     * 组件名称
     */
    private String name;

    /**
     * 组件的值
     */
    private String value;

    /**
     * 快速格式化, 若value非直接取值需预处理好
     *
     * @param dataForm   表单数据源, 若Value类型为list, 则触发ruleDetail
     * @param ruleForm   表单数据格式: { 字段名: 组件名 }
     * @param ruleDetail 表单明细数据格式: { 字段名: 组件名 }
     */
    public static List<DDFormComponentDto> formatComponentValues(Map<String, ?> dataForm, Map<String, String> ruleForm, Map<String, String> ruleDetail) {
        // 审批流表单参数，设置各表单项值
        List<DDFormComponentDto> formComponentValues = new ArrayList<>();
        for (String key : ruleForm.keySet()) {
            if (dataForm.get(key) instanceof List) {
                // 明细组件: 每一个组件都是集合, table为集合嵌套集合
                List<List<DDFormComponentDto>> formComponentDetailsValues = new ArrayList<>();
                List<Map> details = (List<Map>) dataForm.get(key);
                for (Map detail : details) {
                    List<DDFormComponentDto> detailComponentValues = new ArrayList<>();
                    for (String sub : ruleDetail.keySet()) {
                        detailComponentValues.add(DDFormComponentDto.builder().name(ruleDetail.get(sub)).value(String.valueOf(detail.get(sub))).build());
                    }
                    formComponentDetailsValues.add(detailComponentValues);
                }
                formComponentValues.add(DDFormComponentDto.builder().name(ruleForm.get(key)).value(JSON.toJSONString(formComponentDetailsValues)).build());
            } else {
                formComponentValues.add(DDFormComponentDto.builder().name(ruleForm.get(key)).value(String.valueOf(dataForm.get(key))).build());
            }
        }
        return formComponentValues;
    }

    /**
     * 快速格式化, 上传釘盘的文件转为OA审批对象
     */
    public static String formatAttachment(Map dentry) {
        Map data = UtilMap.map("spaceId, fileName, fileSize, fileType, fileId", "spaceId, name, size, extension, id", dentry);
        return JSON.toJSONString(Arrays.asList(data));
    }
}
