package com.malk.service.dingtalk;

import java.util.List;
import java.util.Map;

/**
 * 考勤
 *
 * @apiNote https://open.dingtalk.com/document/orgapp/attendance-overview
 */
public interface DDClient_Attendance {

    /**
     * 获取打卡结果
     *
     * @param userIdList   企业内的员工ID列表，最大值50;
     * @param workDateFrom 和workDateTo参数相隔最多7天（包含7天）; 格式为“yyyy-MM-dd HH:mm:ss”，HH:mm:ss可以使用00:00:00，将返回此日期从0点到24点的结果
     * @param offset       表示获取考勤数据的起始点, 下次获取传的offset值为之前的offset+limit; 表示获取考勤数据的条数，最大值50。
     * @param isI18n       是否为海外企业使用: true：海外平台使用, false（默认）：国内平台使用
     * @apiNote https://open.dingtalk.com/document/orgapp/open-attendance-clock-in-data
     */
    List<Map> listAttendanceResult(String access_token, String[] userIdList, String workDateFrom, String workDateTo, Number offset, Number size, boolean isI18n);

    /**
     * 获取打卡详情
     *
     * @param userIds       企业内的员工ID列表，最大值50;
     * @param checkDateFrom checkDateFrom 和workDateTo参数相隔最多7天（包含7天）; 注: 参数传"2021-12-01 18:00:00"，员工在19:00的打卡信息获取不到
     * @param isI18n        是否为海外企业使用: true：海外平台使用, false（默认）：国内平台使用
     * @apiNote https://open.dingtalk.com/document/orgapp/attendance-clock-in-record-is-open
     */
    List<Map> listAttendanceRecord(String access_token, List userIds, String checkDateFrom, String checkDateTo, boolean isI18n);

    /**
     * 上传打卡记录 [接口已下架, 需要开通专业版联系官方开权限]
     *
     * @apiNote https://open.dingtalk.com/document/isvapp/upload-punch-records
     */
    boolean uploadAttendanceRecord(String access_token, String userId, String deviceName, String deviceId, String photoUrl, long userCheckTime);
}
