package com.malk.service.dingtalk;

import java.util.List;
import java.util.Map;

/**
 * 钉钉通讯录管理
 *
 * @apiNote https://open.dingtalk.com/document/orgapp/contacts-overview
 */
public interface DDClient_Contacts {

    /**
     * 获取子部门ID列表 [获取企业部门下的所有直属子部门列表]
     */
    List<Long> listSubDepartmentId(String access_token, Number dept_id);

    /**
     * 获取部门列表
     */
    List<Map> listSubDepartmentDetail(String access_token, Number dept_id);

    /**
     * 获取部门用户userid列表 [无需分页]
     *
     * @apiNote https://open.dingtalk.com/document/orgapp/query-the-list-of-department-userids
     */
    List<String> listDepartmentUserId(String access_token, Number dept_id);

    /**
     * 查询用户详情
     */
    Map getUserInfoById(String access_token, String userId);

    /**
     * 根据手机号查询用户
     */
    Map getUserInfoByMobile(String access_token, String mobile);

    /**
     * 删除用户
     */
    boolean deleteUser(String access_token, String userId);

    /**
     * 创建用户
     */
    Map createUser(String access_token, String name, String mobile, List<String> dept_id_list, Map body_ext);

    /**
     * 创建部门
     *
     * @apiNote https://open.dingtalk.com/document/orgapp/create-a-department-v2
     */
    Map createDepartment(String access_token, String name, long parent_id, Map body_ext);

}
